@@ -4,7 +4,12 @@ print.calf <- function(x, ...){
   if (x$randomize == TRUE) cat("Randomized Output:", "\n", "\n")
   if (!is.null(x$proportion)) cat("Proportion of Data:", x$proportion, "\n", "\n")
   print.data.frame(x$selection, row.names = FALSE)
-  cat("\nAUC:", x$auc)
+  if (x$targetVec == "binary") {
+    cat("\nAUC:", x$auc)
+    cat("\nFinal p-value:", x$finalBest)
+  } else {
+    cat("\nFinal Correlation:", x$finalBest)
+  }
 }
 
 #'@method print calf_randomize
@@ -13,27 +18,42 @@ print.calf_randomize <- function(x, ...){
   if (x$times == 1) {
     cat("Randomized Output Across", x$times, "Replication:", "\n", "\n")
     print.data.frame(x$selection, row.names = FALSE)
-    cat("\nAUC:", x$auc)
+    if (x$targetVec == "binary") {
+      cat("\nAUC:", x$auc)
+      cat("\nFinal p-value:", x$finalBest)
+    } else {
+      cat("\nFinal Correlation:", x$finalBest)
+    }
   } else {
     cat("Randomized Output Across", x$times, "Replications:", "\n", "\n")
     print.data.frame(x$multiple, row.names = FALSE)
-    cat("\n", "\n")
-    print.data.frame(x$auc, row.names = F)
+    if (x$targetVec == "binary"){
+      cat("\n", "\n")
+      print.data.frame(x$auc, row.names = F)
+    }
   }
 }
 
+
 #'@method print calf_subset
 #'@export
 print.calf_subset <- function(x, ...){
   if (x$times == 1) {
     cat("Proportion =", x$proportion, "Output Across", x$times, "Replication:", "\n", "\n")
     print.data.frame(x$selection, row.names = FALSE)
-    cat("\nAUC:", x$auc)
+    if (x$targetVec == "binary") {
+      cat("\nAUC:", x$auc)
+      cat("\nFinal p-value:", x$finalBest)
+    } else {
+      cat("\nFinal Correlation:", x$finalBest)
+    }
   } else {
     cat("Proportion =", x$proportion, "Output Across", x$times, "Replications:", "\n", "\n")
     print.data.frame(x$multiple, row.names = FALSE)
-    cat("\n", "\n")
-    print.data.frame(x$auc, row.names = F)
+    if (x$targetVec == "binary"){
+      cat("\n", "\n")
+      print.data.frame(x$auc, row.names = F)
+    }
   }
 }
 
